@@ -1,5 +1,6 @@
 from blueness import module
 
+from bluer_options.env import CYAN, NC
 from bluer_objects import file, objects
 from bluer_objects.metadata import post_to_object
 
@@ -33,6 +34,8 @@ def post_process(object_name: str) -> bool:
         return success
     output = [line for line in output if line]
 
+    print("\n".join([CYAN] + output + [NC]))
+
     return post_to_object(
         object_name,
         "post_process",
